# Disable the automatically set build flags to the environment variables such
# as CC, CFLAGS, and etc.
# See <https://src.fedoraproject.org/rpms/redhat-rpm-config/blob/rawhide/f/macros>.
%undefine _auto_set_build_flags

Name: simde
Version: v0.8.2
Release: 1.20241128034000659145.pr1238.59.g77a9a1f8%{?dist}
Summary: Dummy
License: MIT
URL: https://github.com/simd-everywhere/simde
# This value is magically replaced with the archive tar.gz file created by
# `git archive` in the process of the CI.
# Set the existing file `README.md` in case of creating SRPM from this RPM spec
# file on local for testing purpose.
Source0: simde-v0.8.2.tar.gz
# A path to the CI script.
Source1: ci.sh

# List up the needed RPM package names to test here.
# clang, clang++
BuildRequires: clang
BuildRequires: gcc
# g++
BuildRequires: gcc-c++
# ninja
BuildRequires: ninja-build
# pip and setuptools are needed to install and use meson PyPI package.
BuildRequires: python3-devel
BuildRequires: python3-pip
BuildRequires: python3-setuptools
# The GNU time (/bin/time) is used for testing. Use this GNU time rather than
# the embedded time function in bash.
# https://www.gnu.org/software/time/
BuildRequires: time

# RPM package description.
%description

# The bash commands to prepare are executed.
%prep
# Print the replaced value of the Source0.
echo "Source0: %{SOURCE0}"
# Create a dummy file for a valid RPM spec file.
touch dummy.txt

# The bash commands to test are executed.
%check
# Check the directory structure in the tar.gz file.
tar tzvf "%{SOURCE0}" > source_files.txt
head -2 source_files.txt
# Check if the submodule munit is included.
grep munit source_files.txt
# Extract the source archive file.
tar xzf "%{SOURCE0}"

pushd simde-*
# Set the flags used to build the actual RPM package.
# These can be used in the CI testing script.
%global toolchain clang
export CI_CLANG_RPM_CFLAGS="%{build_cflags}"
export CI_CLANG_RPM_CXXFLAGS="%{build_cxxflags}"
export CI_CLANG_RPM_LDFLAGS="%{build_ldflags}"
%global toolchain gcc
export CI_GCC_RPM_CFLAGS="%{build_cflags}"
export CI_GCC_RPM_CXXFLAGS="%{build_cxxflags}"
export CI_GCC_RPM_LDFLAGS="%{build_ldflags}"

echo "Running the CI script %{SOURCE1}."
/bin/time -f '=> [%E]' "%{SOURCE1}"
popd

# Files included in the built RPM package.
%files
%doc dummy.txt

# Changelog entries for the RPM package.
%changelog
* Thu Nov 28 2024 Packit <hello@packit.dev> - v0.8.2-1.20241128034000659145.pr1238.59.g77a9a1f8
- should use INT64_C (jinbo)
- loongarch: add lsx support for sse2.h (yuanhecai)
- x86/avx: Adding overflow test for avx (Quang Vinh Dang)
- fix clang type redef error (Junhyeok Ahn)
- Whoops, missing comma (David Lowndes)
- gh-actions macos 12: deprecated, going offline on 2024-12-03 (Michael R. Crusoe)
- gh-actions msvc-arm64: turn off due to compiler issue (Michael R. Crusoe)
- gh-actions macos: xcode 14.3.1 is no longer available, switch to macos-15 to test xcode 16.0 (Michael R. Crusoe)
- gh-actions: upgrade Ubuntu Mantic to Ubuntu Noble (24.04) (Michael R. Crusoe)
- circleci: switch container for gcc11 i686 -O2 test (Michael R. Crusoe)
- gh-actions: pin emsdk to earlier version until https://github.com/llvm/llvm-project/issues/117200 is fixed and released (Michael R. Crusoe)
- gh-actions: clean up install list (Michael R. Crusoe)
- gh-actions: add loongarch64 clang-18 test (Michael R. Crusoe)
- loongarch float16: use a portable version to avoid compilation errors (gxw)
- x86: move definition of 'value' to correct branch in _mm_loadl_epi64 (Gabriel Hege)
- x86: some better implementations for MSVC and others without SIMDE_STATEMENT_EXPR_ (Michael R. Crusoe)
- gh-actions: tests aarch64 without extra features (Michael R. Crusoe)
- arm crc32: define SIMDE_ARCH_ARM_CRC32 and consistently use it (Michael R. Crusoe)
- _mm256_storeu_pd and _mm256_loadu_pd using 128 bit lanes (Alex K)
- gcc-14 -O3 complained about some possible unitialized values (Michael R. Crusoe)
- neon/cvz z/Arch: stop using deprecated functions. (Michael R. Crusoe)
- gh-actions: upgrade gcc-qemu to gcc-14 (Michael R. Crusoe)
- gh-actions: add CI testing for gcc 11 aarch64/arm64 (Michael R. Crusoe)
- arm neon: avoid GCC 11 vst1_*_x4 built-in functions (LI Qingwu)
- arm neon: fix arm64 gcc11 build excess elements in vector failure (LI Qingwu)
- gh-actions: test loongson + lsx with gcc14 from Ubuntu Oracular (Michael R. Crusoe)
- x86/sse: Fix type convert error for LSX. (Shiyou Yin)
- gh-actions: upgrade to Ubuntu 24.04 LTS; upgrade/add GCC 13 / clang 18 (Michael R. Crusoe)
- arm wasm: add vst2_u8 translation to Wasm SIMD (wrv)
- arm wasm: add vshll translations to Wasm SIMD (wrv)
- arm wasm: add vst4_u8 translation to Wasm SIMD (wrv)
- appveyor: stop testing with MSVC 2022 until they fix their regressions (Michael R. Crusoe)
- math: typo fix, check SIMDE_MATH_NANF instead of the old-style SIMDE_NANF (Michael R. Crusoe)
- wasm AltiVec: add u16x8 and u8x16 avgr translations (wrv)
- wasm NEON: add u16x8 and u8x16 avgr translations (wrv)
- arm neon vminnmv_f16: remove duplicate statement (#1208) (Michael R. Crusoe)
- x86 wasm: Wasm SIMD version of `_mm_sad_epu8` (wrv)
- msvc: add simde_MemoryBarrier to avoid including <windows.h> (Dimo Markov)
- x86/fma: Use 128 bit fnmadd_pd to do 256 bit fnmadd_pd (#1197) (AlexK-BD)
- gh-actions: ensure that gcov is present when needed (Michael R. Crusoe)
- meson: 0.55.1 is needed for Python 3.12+ (Michael R. Crusoe)
- pow: consistently use simde_math_pow (Michael R. Crusoe)
- gh-actions: GitHub has retired the macos-11 runners, add some more -13 (x86-64) and -14 (arm64) testing (Michael R. Crusoe)
- x86: remove redundant mm_add_pd translation for WASM (#1190) (Willy R. Vasquez)
-  arm/neon riscv64: additional RVV implementations - part 2. (#1189) (Chi-Wei Chu)
- arm/neon riscv64: additional RVV implementations - part1 (#1188) (Ruhung)
- Use _Float16 in C++ on aarch64 with GCC 13+ (Michael Catanzaro)
- Don't use _Float16 on non-SSE2 x86 (Michael Catanzaro)
- Don't use _Float16 on s390x (Michael Catanzaro)
- x86: Apply half tabular method in _mm_crc32 family (Cuda Chen)
- arm: improve performance in vqadd and vmvn in risc-v (Zhijin Zeng)
- neon: avoid warnings when "__ARM_NEON_FP" is not defined. (Carlos Alberto Lopez Perez)
-  Add @zengdage as a contributor (Michael R. Crusoe)
-  Add @howjmay as a contributor (Michael R. Crusoe)
-  Add @Torinde as a contributor (Michael R. Crusoe)
-  Add @eric900115 as a contributor (Michael R. Crusoe)
-  Add @AymenQ as a contributor (Michael R. Crusoe)
- add git mail map (Michael R. Crusoe)
- start next development cycle: v0.8.3 (Michael R. Crusoe)

* Fri Jun 02 2023 Dummy Dummy <dummy@dummy.com> - 1-1
- Dummy.
